PuzzlifyConfig class

Constructors

PuzzlifyConfig({required Color borderSelectColor, required BorderRadius borderRadius, double borderSelectWidth = 2, double verticalSpace = 5, double horizontalSpace = 5})

Properties

borderRadius BorderRadius
final
borderSelectColor Color
final
borderSelectWidth double
final
hashCode int
The hash code for this object.
no setterinherited
horizontalSpace double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verticalSpace double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited